.. :Instrument:

Instrument
==========

.. currentmodule:: Instrument



.. autosummary::
   :nosignatures:

    Instrument.Instrument
    Instrument.Instrument.append
    Instrument.Instrument.plot
    Instrument.Instrument.initialize
    Instrument.Instrument.saveXML
    Instrument.Instrument.generateCAMEAXML
    Instrument.Instrument.generateCalibration
    Instrument.convertToHDF

	


Instrument Object and Methods
-----------------------------


.. automodule:: Instrument

.. _Instrument:

.. autoclass:: Instrument
    :members:

    .. automethod:: __init__

.. autofunction:: Instrument.convertToHDF
